[PATCH 2/7] firesat: rename to firedtv

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Suggested by Andreas Monitzer.  Besides DVB-S/-S2 receivers, the driver
also supports DVB-C and DVB-T receivers, hence the previous project name
is too narrow now.

Not yet done:  Rename source directory, files, types, variables...

Signed-off-by: Stefan Richter <stefanr at s5r6.in-berlin.de>
---
 drivers/media/dvb/Makefile               |    2 +-
 drivers/media/dvb/firesat/Kconfig        |   13 +++++++------
 drivers/media/dvb/firesat/Makefile       |    4 ++--
 drivers/media/dvb/firesat/avc_api.c      |    2 +-
 drivers/media/dvb/firesat/cmp.c          |    2 +-
 drivers/media/dvb/firesat/firesat-ci.c   |    2 +-
 drivers/media/dvb/firesat/firesat-rc.c   |    2 +-
 drivers/media/dvb/firesat/firesat.h      |    2 +-
 drivers/media/dvb/firesat/firesat_1394.c |   16 ++++++++--------
 drivers/media/dvb/firesat/firesat_dvb.c  |    2 +-
 drivers/media/dvb/firesat/firesat_fe.c   |    8 ++++----
 11 files changed, 28 insertions(+), 27 deletions(-)

Index: linux/drivers/media/dvb/Makefile
===================================================================
--- linux.orig/drivers/media/dvb/Makefile
+++ linux/drivers/media/dvb/Makefile
@@ -4,4 +4,4 @@
 
 obj-y        := dvb-core/ frontends/ ttpci/ ttusb-dec/ ttusb-budget/ b2c2/ bt8xx/ cinergyT2/ dvb-usb/ pluto2/
 
-obj-$(CONFIG_DVB_FIRESAT)	+= firesat/
+obj-$(CONFIG_DVB_FIREDTV)	+= firesat/
Index: linux/drivers/media/dvb/firesat/Kconfig
===================================================================
--- linux.orig/drivers/media/dvb/firesat/Kconfig
+++ linux/drivers/media/dvb/firesat/Kconfig
@@ -1,11 +1,12 @@
-config DVB_FIRESAT
-	tristate "FireSAT devices"
+config DVB_FIREDTV
+	tristate "FireDTV (FireWire attached DVB receivers)"
 	depends on DVB_CORE && IEEE1394
 	help
-	  Support for external IEEE1394 adapters designed by Digital Everywhere and
-	  produced by El Gato, shipped under the brand name 'FireDTV/FloppyDTV'.
+	  Support for IEEE 1394 DVB receivers designed by Digital Everywhere,
+	  known as FireDTV and FloppyDTV, and EyeTV 300/400 from Elgato.
 
-	  These devices don't have a MPEG decoder built in, so you need
+	  These devices don't have an MPEG decoder built in, so you need
 	  an external software decoder to watch TV.
 
-	  Say Y if you own such a device and want to use it.
+	  To compile this driver as a module, say M here: the module will be
+	  called firedtv.
Index: linux/drivers/media/dvb/firesat/Makefile
===================================================================
--- linux.orig/drivers/media/dvb/firesat/Makefile
+++ linux/drivers/media/dvb/firesat/Makefile
@@ -1,4 +1,4 @@
-firesat-objs := firesat_1394.o	\
+firedtv-objs := firesat_1394.o	\
 		firesat_dvb.o	\
 		firesat_fe.o	\
 		firesat_iso.o	\
@@ -7,7 +7,7 @@ firesat-objs := firesat_1394.o	\
 		firesat-rc.o	\
 		firesat-ci.o
 
-obj-$(CONFIG_DVB_FIRESAT) += firesat.o
+obj-$(CONFIG_DVB_FIREDTV) += firedtv.o
 
 EXTRA_CFLAGS := -Idrivers/ieee1394
 EXTRA_CFLAGS += -Idrivers/media/dvb/dvb-core
Index: linux/drivers/media/dvb/firesat/avc_api.c
===================================================================
--- linux.orig/drivers/media/dvb/firesat/avc_api.c
+++ linux/drivers/media/dvb/firesat/avc_api.c
@@ -1,5 +1,5 @@
 /*
- * FireSAT AVC driver
+ * FireDTV driver (formerly known as FireSAT)
  *
  * Copyright (C) 2004 Andreas Monitzer <andy at monitzer.com>
  * Copyright (C) 2008 Ben Backx <ben at bbackx.com>
Index: linux/drivers/media/dvb/firesat/cmp.c
===================================================================
--- linux.orig/drivers/media/dvb/firesat/cmp.c
+++ linux/drivers/media/dvb/firesat/cmp.c
@@ -1,5 +1,5 @@
 /*
- * FireSAT DVB driver
+ * FireDTV driver (formerly known as FireSAT)
  *
  * Copyright (C) 2004 Andreas Monitzer <andy at monitzer.com>
  * Copyright (C) 2008 Henrik Kurelid <henrik at kurelid.se>
Index: linux/drivers/media/dvb/firesat/firesat-ci.c
===================================================================
--- linux.orig/drivers/media/dvb/firesat/firesat-ci.c
+++ linux/drivers/media/dvb/firesat/firesat-ci.c
@@ -1,5 +1,5 @@
 /*
- * FireSAT DVB driver
+ * FireDTV driver (formerly known as FireSAT)
  *
  * Copyright (C) 2004 Andreas Monitzer <andy at monitzer.com>
  * Copyright (C) 2008 Henrik Kurelid <henrik at kurelid.se>
Index: linux/drivers/media/dvb/firesat/firesat-rc.c
===================================================================
--- linux.orig/drivers/media/dvb/firesat/firesat-rc.c
+++ linux/drivers/media/dvb/firesat/firesat-rc.c
@@ -1,5 +1,5 @@
 /*
- * FireSAT AVC driver
+ * FireDTV driver (formerly known as FireSAT)
  *
  * Copyright (C) 2004 Andreas Monitzer <andy at monitzer.com>
  *
Index: linux/drivers/media/dvb/firesat/firesat.h
===================================================================
--- linux.orig/drivers/media/dvb/firesat/firesat.h
+++ linux/drivers/media/dvb/firesat/firesat.h
@@ -1,5 +1,5 @@
 /*
- * FireSAT DVB driver
+ * FireDTV driver (formerly known as FireSAT)
  *
  * Copyright (C) 2004 Andreas Monitzer <andy at monitzer.com>
  * Copyright (C) 2008 Henrik Kurelid <henrik at kurelid.se>
Index: linux/drivers/media/dvb/firesat/firesat_dvb.c
===================================================================
--- linux.orig/drivers/media/dvb/firesat/firesat_dvb.c
+++ linux/drivers/media/dvb/firesat/firesat_dvb.c
@@ -1,5 +1,5 @@
 /*
- * FireSAT DVB driver
+ * FireDTV driver (formerly known as FireSAT)
  *
  * Copyright (C) 2004 Andreas Monitzer <andy at monitzer.com>
  * Copyright (C) 2008 Henrik Kurelid <henrik at kurelid.se>
Index: linux/drivers/media/dvb/firesat/firesat_1394.c
===================================================================
--- linux.orig/drivers/media/dvb/firesat/firesat_1394.c
+++ linux/drivers/media/dvb/firesat/firesat_1394.c
@@ -1,5 +1,5 @@
 /*
  * FireSAT DVB driver
  *
  * Copyright (C) 2004 Andreas Monitzer <andy at monitzer.com>
  * Copyright (C) 2007-2008 Ben Backx <ben at bbackx.com>
@@ -87,7 +87,7 @@ static void fcp_request(struct hpsb_host
 			size_t length);
 
 static struct hpsb_highlevel firesat_highlevel = {
-	.name		= "FireSAT",
+	.name		= "FireDTV",
 	.add_host	= firesat_add_host,
 	.remove_host	= firesat_remove_host,
 	.host_reset	= firesat_host_reset,
@@ -339,7 +339,7 @@ static int firesat_update(struct unit_di
 
 static struct hpsb_protocol_driver firesat_driver = {
 
-	.name		= "FireSAT",
+	.name		= "FireDTV",
 	.id_table	= firesat_id_table,
 	.update		= firesat_update,
 
@@ -356,11 +356,11 @@ static int __init firesat_init(void)
 {
 	int ret;
 
-	printk(KERN_INFO "FireSAT loaded\n");
+	printk(KERN_INFO "FireDTV loaded\n");
 	hpsb_register_highlevel(&firesat_highlevel);
 	ret = hpsb_register_protocol(&firesat_driver);
 	if (ret) {
-		printk(KERN_ERR "FireSAT: failed to register protocol\n");
+		printk(KERN_ERR "FireDTV: failed to register protocol\n");
 		hpsb_unregister_highlevel(&firesat_highlevel);
 		return ret;
 	}
@@ -377,7 +377,7 @@ static void __exit firesat_exit(void)
 {
 	hpsb_unregister_protocol(&firesat_driver);
 	hpsb_unregister_highlevel(&firesat_highlevel);
-	printk(KERN_INFO "FireSAT quit\n");
+	printk(KERN_INFO "FireDTV quit\n");
 }
 
 module_init(firesat_init);
@@ -385,6 +385,6 @@ module_exit(firesat_exit);
 
 MODULE_AUTHOR("Andreas Monitzer <andy at monitzer.com>");
 MODULE_AUTHOR("Ben Backx <ben at bbackx.com>");
-MODULE_DESCRIPTION("FireSAT DVB Driver");
+MODULE_DESCRIPTION("FireDTV DVB Driver");
 MODULE_LICENSE("GPL");
-MODULE_SUPPORTED_DEVICE("FireSAT DVB");
+MODULE_SUPPORTED_DEVICE("FireDTV DVB");
@@ -1,5 +1,5 @@
 /*
- * FireSAT DVB driver
+ * FireDTV driver (formerly known as FireSAT)
  *
  * Copyright (C) 2004 Andreas Monitzer <andy at monitzer.com>
Index: linux/drivers/media/dvb/firesat/firesat_fe.c
===================================================================
--- linux.orig/drivers/media/dvb/firesat/firesat_fe.c
+++ linux/drivers/media/dvb/firesat/firesat_fe.c
@@ -1,5 +1,5 @@
 /*
  * FireSAT DVB driver
  *
  * Copyright (C) 2004 Andreas Monitzer <andy at monitzer.com>
  * Copyright (C) 2008 Henrik Kurelid <henrik at kurelid.se>
@@ -235,7 +235,7 @@ int firesat_frontend_attach(struct fires
 
 static struct dvb_frontend_info firesat_S_frontend_info = {
 
-	.name			= "FireSAT DVB-S Frontend",
+	.name			= "FireDTV DVB-S Frontend",
 	.type			= FE_QPSK,
 
 	.frequency_min		= 950000,
@@ -256,7 +256,7 @@ static struct dvb_frontend_info firesat_
 
 static struct dvb_frontend_info firesat_C_frontend_info = {
 
-	.name			= "FireSAT DVB-C Frontend",
+	.name			= "FireDTV DVB-C Frontend",
 	.type			= FE_QAM,
 
 	.frequency_min		= 47000000,
@@ -276,7 +276,7 @@ static struct dvb_frontend_info firesat_
 
 static struct dvb_frontend_info firesat_T_frontend_info = {
 
-	.name			= "FireSAT DVB-T Frontend",
+	.name			= "FireDTV DVB-T Frontend",
 	.type			= FE_OFDM,
 
 	.frequency_min		= 49000000,
@@ -1,5 +1,5 @@
 /*
- * FireSAT DVB driver
+ * FireDTV driver (formerly known as FireSAT)
  *
  * Copyright (C) 2004 Andreas Monitzer <andy at monitzer.com>

-- 
Stefan Richter
-=====-==--- =--- ==---
http://arcgraph.de/sr/



[Index of Archives]     [Linux Driver Backports]     [DMA Engine]     [Linux GPIO]     [Linux SPI]     [Video for Linux]     [Linux USB Devel]     [Linux Coverity]     [Linux Audio Users]     [Linux Kernel]     [Linux SCSI]     [Yosemite Backpacking]
  Powered by Linux